@@ -1,14 +1,14 @@
-corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select = "p.value", family = "auto", use = "pairwise.complete.obs", method = "pearson") {
-
-  # version 2.9 (2 May 2022)
-
+corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select = "p.value", family = "auto", use = "pairwise.complete.obs", method = "pearson", verbosity = 1) {
+  
+  # version 3.1 (12 Oct 2022)
+  
   if (length(sp.cols) > 1) stop ("Sorry, 'corSelect' is currently implemented for only one 'sp.col' at a time.")
-
+  
   univar.criteria <- c("VIF")
   bivar.criteria <- c("p.value", "AIC", "BIC")
-
+  
   if (!(select %in% c(univar.criteria, bivar.criteria))) stop ("Invalid 'select' criterion.")
-
+  
   data <- as.data.frame(data)
   if (!is.null(sp.cols) & select %in% bivar.criteria) {
     n.in <- nrow(data)
@@ -16,11 +16,11 @@ corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select =
     n.out <- nrow(data)
     if (n.out < n.in)  warning (n.in - n.out, " observations removed due to missing data in 'sp.cols'; ", n.out, " observations actually evaluated.")
   }
-
+  
   cor.mat <- cor(data[ , var.cols], use = use, method = method)
   cor.mat[upper.tri(cor.mat, diag = TRUE)] <- NA
   high.cor.mat <- bivar.mat <- numeric(0)
-
+  
   if (max(abs(cor.mat), na.rm = TRUE) >= cor.thresh) {
     high.cor.rowcol <- as.matrix(which(abs(cor.mat) >= cor.thresh, arr.ind = TRUE))
     high.cor.inds <- sort(unique(as.vector(high.cor.rowcol)))
@@ -28,20 +28,19 @@ corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select =
     high.cor.mat$corr <- NULL
     for (r in 1:nrow(high.cor.mat))  high.cor.mat$corr[r] <- cor.mat[high.cor.rowcol[ ,"row"][r], high.cor.rowcol[ ,"col"][r]]
     high.cor.mat <- high.cor.mat[order(abs(high.cor.mat$corr), decreasing = TRUE), ]
-
+    
     if (is.null(sp.cols) & select %in% bivar.criteria) {
       message(select, " 'select' criterion not assessable without a response variable ('sp.cols'). Returning high pairwise correlations among 'var.cols'.")
       return (high.cor.mat)
     }
-
+    
     high.cor.vars <- unique(rownames(cor.mat[high.cor.inds, high.cor.inds]))
-
+    
     if (select %in% bivar.criteria) {
-      bivar.mat <- FDR(data = data, sp.cols = sp.cols, var.cols = match(high.cor.vars, colnames(data)), family = family, simplif = TRUE)[ , c("p.value", "AIC", "BIC")]
-      if (isTRUE(all.equal(order(bivar.mat[ , c("p.value")]), order(bivar.mat[ , c("AIC")]), order(bivar.mat[ , c("BIC")]), tolerance = 1.5e-8)))  message("Results identical whether using p-value, AIC or BIC to select variables.\n")
-      else message("Results NOT identical whether using p-value, AIC or BIC to select variables.\n")
+      bivar.mat <- FDR(data = data, sp.cols = sp.cols, var.cols = match(high.cor.vars, colnames(data)), family = family, simplif = TRUE, verbosity = 0)[ , c("p.value", "AIC", "BIC")]
+      if (isTRUE(all.equal(order(bivar.mat[ , c("p.value")]), order(bivar.mat[ , c("AIC")]), order(bivar.mat[ , c("BIC")]), tolerance = 1.5e-8)))  message("Results identical whether using p-value, AIC or BIC to select among correlated variables.\n") else message("Results NOT identical whether using p-value, AIC or BIC to select among correlated variables.\n")
     }  # end if select in bivar
-
+    
     data.remaining <- data[ , var.cols]
     while (max(abs(cor.mat), na.rm = TRUE) >= cor.thresh) {
       max.cor.ind <- which(abs(cor.mat) == max(abs(cor.mat), na.rm = TRUE), arr.ind = TRUE)
@@ -54,7 +53,7 @@ corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select =
       else if (select %in% bivar.criteria) {
         targets <- bivar.mat[c(v1, v2), select, drop = FALSE]
       }  # end if bivar
-
+      
       exclude <- which.max(as.matrix(targets))
       excl.name <- rownames(targets)[exclude]
       excl.ind <- match(excl.name, colnames(cor.mat))
@@ -63,16 +62,29 @@ corSelect <- function(data, sp.cols = NULL, var.cols, cor.thresh = 0.8, select =
       if (all(is.na(cor.mat))) cor.mat <- numeric(0)
       if (length(cor.mat) == 0) break
     }  # end while max
-
+    
   }  # end if max > thresh
-
-    selected.vars <- colnames(cor.mat)
-    selected.var.cols <- match(colnames(cor.mat), colnames(data))
-    if (is.character(var.cols)) var.cols <- which(colnames(data) %in% var.cols)  # new
-    excluded.vars <- colnames(data)[var.cols][!(colnames(data)[var.cols] %in% colnames(cor.mat))]
-
+  
+  selected.vars <- colnames(cor.mat)
+  selected.var.cols <- match(colnames(cor.mat), colnames(data))
+  if (is.character(var.cols)) var.cols <- which(colnames(data) %in% var.cols)  # new
+  excluded.vars <- colnames(data)[var.cols][!(colnames(data)[var.cols] %in% colnames(cor.mat))]
+  
   vif2 <- multicol(data[ , selected.var.cols, drop = FALSE])
+  
+  if (verbosity > 0) {
+    message(length(excluded.vars), " variable(s) excluded, ",
+            length(selected.vars), " selected")
+  }
 
+  if (verbosity > 1) {
+    cat("\nEXCLUDED:\n")
+    cat(excluded.vars, sep = ", ")
+    cat("\n\nSELECTED:\n")
+    cat(selected.vars, sep = ", ")
+    cat("\n")
+  }
+  
   list(high.correlations = high.cor.mat,
        bivariate.significance = bivar.mat,
        excluded.vars = excluded.vars,
