@@ -1,7 +1,7 @@
-fuzzyRangeChange <- function(pred1, pred2, number = TRUE, prop = TRUE, na.rm = TRUE, round.digits = 2, measures = c("Gain", "Loss", "Stable presence", "Stable absence", "Balance"), plot = TRUE, ...) #col = colorRampPalette(c("white", "black"))(length(measures)) 
+fuzzyRangeChange <- function(pred1, pred2, number = TRUE, prop = TRUE, na.rm = TRUE, round.digits = 2, measures = c("Gain", "Loss", "Stable positive", "Stable negative", "Balance"), plot = TRUE, x.lab = TRUE, ...) #col = colorRampPalette(c("white", "black"))(length(measures)) 
   {
   
-  # version 1.7 (2 May 2022)
+  # version 1.8 (7 Jul 2022)
   
   pred1 <- unlist(pred1)
   pred2 <- unlist(pred2)
@@ -20,8 +20,8 @@ fuzzyRangeChange <- function(pred1, pred2, number = TRUE, prop = TRUE, na.rm = T
   names(values) <- measures
   if ("Gain" %in% measures)  values["Gain"] <- sum(fuzzyOverlay(data.frame(pred1, pred2), op = "expansion", na.rm = na.rm), na.rm = na.rm)
   if ("Loss" %in% measures)  values["Loss"] <- sum(fuzzyOverlay(data.frame(pred1, pred2), op = "contraction", na.rm = na.rm), na.rm = na.rm)
-  if ("Stable presence" %in% measures)  values["Stable presence"] <- sum(fuzzyOverlay(data.frame(pred1, pred2), op = "maintenance", na.rm = na.rm), na.rm = na.rm)
-  if ("Stable absence" %in% measures)  values["Stable absence"] <- sum(fuzzyOverlay(1 - data.frame(pred1, pred2), op = "maintenance", na.rm = na.rm), na.rm = na.rm)
+  if ("Stable positive" %in% measures)  values["Stable positive"] <- sum(fuzzyOverlay(data.frame(pred1, pred2), op = "maintenance", na.rm = na.rm), na.rm = na.rm)
+  if ("Stable negative" %in% measures)  values["Stable negative"] <- sum(fuzzyOverlay(1 - data.frame(pred1, pred2), op = "maintenance", na.rm = na.rm), na.rm = na.rm)
   if ("Balance" %in% measures)  values["Balance"] <- sum(fuzzyOverlay(data.frame(pred1, pred2), op = "change", na.rm = na.rm), na.rm = na.rm)
   
   result <- data.frame(Measure = measures, Number = values)
@@ -30,9 +30,9 @@ fuzzyRangeChange <- function(pred1, pred2, number = TRUE, prop = TRUE, na.rm = T
     if (na.rm) n <- length(na.omit(pred1))
     else n <- length(pred1)
     range.size <- sum(pred1, na.rm = na.rm)
-    stable.abs <- result[result$Measure == "Stable absence", "Number"]
+    stable.abs <- result[result$Measure == "Stable negative", "Number"]
     result$Proportion <- result[ , "Number"] / range.size
-    result[result$Measure == "Stable absence", "Proportion"] <- stable.abs / (n - range.size)
+    result[result$Measure == "Stable negative", "Proportion"] <- stable.abs / (n - range.size)
   }
   
   if (!number) {
@@ -40,7 +40,8 @@ fuzzyRangeChange <- function(pred1, pred2, number = TRUE, prop = TRUE, na.rm = T
   }
   
   if (plot) {
-    barplot(result[ , ncol(result)], names.arg = gsub(x = rownames(result), pattern = " ", replacement = "\n"), ...)
+    if (x.lab) xlab <- gsub(x = rownames(result), pattern = " ", replacement = "\n") else xlab <- ""
+    barplot(result[ , ncol(result)], names.arg = xlab, ylab = names(result)[ncol(result)], ...)
     abline(h = 0)
   }
   
